@@ -1,7 +1,7 @@
 import logging
 
 logging.basicConfig(
-    level=logging.DEBUG,
+    level=logging.INFO,
     format="%(asctime)s %(name)-12s %(levelname)-8s %(message)s",
     datefmt="%m-%d %H:%M",
 )
@@ -94,7 +94,8 @@ class VenvLink:
 
         try:
             # Create the virtual environment in the "centralized location"
-            self._create_venv_to_venv_folder(
+            # Note: project_name may change
+            project_name = self._create_venv_to_venv_folder(
                 project_name, system_site_packages=system_site_packages
             )
         except UserAborted:
@@ -112,15 +113,18 @@ class VenvLink:
         ret = self._check_that_venv_does_not_exist(project_name)
 
         if ret == "skipcreate":
-            return
+            return project_name
         if ret == "newname":
             project_name = self._get_new_venv_name()
 
         subprocess_cmd = [sys.executable, "-m", "venv", project_name]
         if system_site_packages:
             subprocess_cmd.append("--system-site-packages")
-        logger.info("Running: %s with cwd=%s", subprocess_cmd, self.venv_folder)
+        logger.info(
+            'Running: "%s" with cwd="%s"', " ".join(subprocess_cmd), self.venv_folder
+        )
         subprocess.run(subprocess_cmd, cwd=self.venv_folder)
+        return project_name
 
     def __venv_exists(self, project_name):
         return (self.venv_folder / project_name).exists()
@@ -182,8 +186,10 @@ class VenvLink:
 
         venvdir_dst = workdir / venvname
         if venvdir_dst.exists():
-            print(f'The "{venvdir_dst}" exists already!')
-            print("Do you want to remove it?")
+            print(f'The activate proxy inside "{venvdir_dst}" exists already!')
+            print(
+                "Do you want to remove it? (This will remove just the link, not the virtual environment it is linked to)"
+            )
 
             prompt = "[Y] Yes [A] Abort: "
             validator = partial(is_in_accepted_values, accepted_values={"Y", "A"})
@@ -212,16 +218,14 @@ class VenvLink:
 
         real_activate_ps1 = venvdir_src / "Scripts" / "Activate.ps1"
         real_activate_bat = venvdir_src / "Scripts" / "activate.bat"
-        # The [ and ] need to be escaped with double backticks.
-        real_activate_ps1 = (
-            str(real_activate_ps1).replace("[", "``[").replace("]", "``]")
-        )
 
         files_and_contents = (
             (
                 "Scripts" + os.path.sep + "Activate.ps1",
-                f"""Write-Output 'venvlink: Activating virtual env in "{venvdir_src}"'
-                & \"{real_activate_ps1}\"""",
+                (
+                    f"""Write-Output 'venvlink: Activating virtual env in "{venvdir_src}"'\n"""
+                    f"& '{real_activate_ps1}'"
+                ),
             ),
             (
                 "Scripts" + os.path.sep + "activate.bat",
@@ -230,7 +234,8 @@ class VenvLink:
                     f"""echo venvlink: Activating virtual env in \"{venvdir_src}\"\n"""
                     f"""call \"{real_activate_bat}\""""
                 ),
-            ),
+            ),  # Dummy file which makes possible to run simply "venv\Scripts\activate"
+            ("Scripts" + os.path.sep + "activate", ""),
         )
 
         for file, content in files_and_contents:
